@@ -1,4 +1,4 @@
-from __future__ import print_function
+
 
 from builtins import str
 import os
@@ -6,8 +6,8 @@ import re
 import math
 from string import Template
 # from datetime import timedelta
+from .mycluster import check_output
 from .mycluster import get_timedelta
-# from subprocess import Popen, PIPE, check_output
 from .mycluster import get_data
 from .mycluster import load_template
 
@@ -110,11 +110,10 @@ def create_submit(queue_id, **kwargs):
     else:
         raise ValueError("num_tasks must be specified")
 
-    tpn = tasks_per_node(queue_id)
-    queue_tpn = tpn
     if 'tasks_per_node' in kwargs:
         tpn = kwargs['tasks_per_node']
-
+    else:
+        tpn = tasks_per_node(queue_id)
     if 'num_threads_per_task' in kwargs:
         num_threads_per_task = kwargs['num_threads_per_task']
     else:
@@ -136,8 +135,6 @@ def create_submit(queue_id, **kwargs):
 
     num_nodes = int(math.ceil(float(num_tasks) / float(tpn)))
 
-    num_queue_slots = num_nodes * queue_tpn
-
     no_syscribe = kwargs.get('no_syscribe', False)
 
     record_job = not no_syscribe
@@ -153,7 +150,6 @@ def create_submit(queue_id, **kwargs):
                                  my_output=my_output,
                                  user_email=user_email,
                                  queue_name=queue_name,
-                                 num_queue_slots=num_queue_slots,
                                  num_tasks=num_tasks,
                                  tpn=tpn,
                                  num_threads_per_task=num_threads_per_task,
@@ -182,21 +178,21 @@ def submit(script_name, immediate, depends_on=None,
                 try:
                     job_id = int(output.split(' ')[-1].strip())
                 except:
-                    print('Job submission failed: ' + output)
+                    print(('Job submission failed: ' + output))
         elif depends_on is not None:
             with os.popen('sbatch %s --kill-on-invalid-dep=yes --dependency=afterok:%s %s' % (additional_cmd, depends_on, script_name)) as f:
                 output = f.readline()
                 try:
                     job_id = int(output.split(' ')[-1].strip())
                 except:
-                    print('Job submission failed: ' + output)
+                    print(('Job submission failed: ' + output))
         else:
             with os.popen('sbatch %s %s' % (additional_cmd, script_name)) as f:
                 output = f.readline()
                 try:
                     job_id = int(output.split(' ')[-1].strip())
                 except:
-                    print('Job submission failed: ' + output)
+                    print(('Job submission failed: ' + output))
                 # Get job id and record in database
     else:
         with os.popen('grep -- "SBATCH -p" ' + script_name + ' | sed \'s/#SBATCH//\'') as f:
@@ -214,15 +210,14 @@ def submit(script_name, immediate, depends_on=None,
             ntasks + ' ' + project + ' ' + job + ' bash ./' + script_name
         print(cmd_line)
 
-        import subprocess
         try:
-            output = subprocess.check_output(cmd_line, shell=True)
+            output = check_output(cmd_line, shell=True)
             try:
                 job_id = int(output.split(' ')[-1].strip())
             except:
-                print('Job submission failed: ' + output)
+                print(('Job submission failed: ' + output))
         except:
-            print('Job submission failed: ' + cmd_line)
+            print(('Job submission failed: ' + cmd_line))
 
     return job_id
 
