@@ -1,6 +1,3 @@
-from __future__ import print_function
-
-
 from . import mycluster
 
 mycluster.init()
@@ -15,4 +12,4 @@ mycluster.create_submit('hybrid:hybrid.q',
 mycluster.submit('test.job', True)
 
 for i in mycluster.job_list():
-    print(' {0} {1}'.format(i, mycluster.get_job(i).status))
+    print((' {0} {1}'.format(i, mycluster.get_job(i).status)))
